@@ -7,6 +7,9 @@
  * Copyright 2015      Gentoo Linux
  * Copyright 2017      Robert Krause <ruport@f00l.de>
  * Copyright 2017      Sharad B
+ * Copyright 2020      David Polverari <david.polverari@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,62 +26,45 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  *
- * packit official page at https://github.com/eribertomota/packit
+ * packit official page at https://github.com/resurrecting-open-source-projects/packit
  */
 
 #include "exit.h"
 
-void injection_clean_exit(int sig) {
-    char a[2];
+void injection_clean_exit(int sig)
+{
+	char a[2];
 
 #ifdef DEBUG
-    fprintf(stdout, "DEBUG: injection_clean_exit(%d)\n", sig);
+	fprintf(stdout, "DEBUG: injection_clean_exit(%d)\n", sig);
 #endif
-
-    if(sig == SIGINT)
-    {
-        while(1)
-        {
-            fprintf(stderr, "\n\nWould you like to quit? (y/n): ");
-            fgets(a, 2, stdin);
-
-            if(!strncasecmp(a, "Y", 1))
-                break;
-            else
-            if(!strncasecmp(a, "N", 1))
-                return;
-        }
-    }
-
-    injection_stats();
-    libnet_destroy(g_pkt_d);
-
-    fprintf(stdout, "\n");
-
+	if (sig == SIGINT) {
+		while (1) {
+			fprintf(stderr, "\n\nWould you like to quit? (y/n): ");
+			if ((fgets(a, 2, stdin) == NULL)
+			    || !strncasecmp(a, "Y", 1))
+				break;
+			else if (!strncasecmp(a, "N", 1))
+				return;
+		}
+	}
+	injection_stats();
+	libnet_destroy(g_pkt_d);
+	fprintf(stdout, "\n");
 #ifdef DEBUG
-    fprintf(stdout, "DEBUG: Good-Bye\n");
+	fprintf(stdout, "DEBUG: Good-Bye\n");
 #endif
-
-    exit(SUCCESS);
-
-    return;
+	exit(EXIT_SUCCESS);
 }
 
-void
-capture_clean_exit(int sig)
+void capture_clean_exit(int sig)
 {
 #ifdef DEBUG
-    fprintf(stdout, "\nDEBUG: capture_clean_exit() SIG: %d\n", sig);
+	fprintf(stdout, "\nDEBUG: capture_clean_exit() SIG: %d\n", sig);
 #endif
-
-    fprintf(stdout, "\n");
-
-    capture_stats();
-    pcap_close(g_pkt);
-
-    fprintf(stdout, "\n");
-
-    exit(SUCCESS);
-
-    return;
+	fprintf(stdout, "\n");
+	capture_stats();
+	pcap_close(g_pkt);
+	fprintf(stdout, "\n");
+	exit(EXIT_SUCCESS);
 }
