@@ -5,6 +5,9 @@
  *
  * Copyright 2002-2004 Darren Bounds <dbounds@intrusense.com>
  * Copyright 2007      Kumar Appaiah <akumar@ee.iitm.ac.in>
+ * Copyright 2020      David Polverari <david.polverari@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +24,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  *
- * packit official page at https://github.com/eribertomota/packit
+ * packit official page at https://github.com/resurrecting-open-source-projects/packit
  */
 
 #ifndef __MAIN_H
@@ -48,10 +51,4 @@
 
 #define OPT_MAXLEN 32
 
-u_int32_t opt;
-char *optarg;
-
-void parse_capture_options(int, char *[]);
-void parse_inject_options(int, char *[], u_int16_t);
-
-#endif /* __MAIN_H */
+#endif				/* __MAIN_H */
