@@ -5,6 +5,9 @@
  *
  * Copyright 2002 Darren Bounds <dbounds@intrusense.com>
  * Copyright 2017 Sharad B
+ * Copyright 2020 David Polverari <david.polverari@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,29 +24,21 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  * MA  02110-1301, USA.
  *
- * packit official page at https://github.com/eribertomota/packit
+ * packit official page at https://github.com/resurrecting-open-source-projects/packit
  */
 
 #include "print_udp_hdr.h"
 
-void
-print_udp_hdr(u_int8_t *packet)
+void print_udp_hdr(u_int8_t * packet)
 {
-    struct libnet_udp_hdr *udphdr;
+	struct libnet_udp_hdr *udphdr;
 
 #ifdef DEBUG
-    fprintf(stdout, "DEBUG: print_udp_hdr()\n");
+	fprintf(stdout, "DEBUG: print_udp_hdr()\n");
 #endif
-
-    udphdr = (struct libnet_udp_hdr *)(packet + IPV4_H + g_hdr_len);
-
-    fprintf(stdout, "UDP header:  Src Port: %d  Dst Port: %d  Len: %d  ",
-        htons(udphdr->uh_sport),
-        htons(udphdr->uh_dport),
-        ntohs(udphdr->uh_ulen));
-
-    fprintf(stdout, "\n");
-
-    return;
+	udphdr = (struct libnet_udp_hdr *)(packet + IPV4_H + g_hdr_len);
+	fprintf(stdout, "UDP header:  Src Port: %d  Dst Port: %d  Len: %d  ",
+		htons(udphdr->uh_sport),
+		htons(udphdr->uh_dport), ntohs(udphdr->uh_ulen));
+	fprintf(stdout, "\n");
 }
-
